@@ -16,6 +16,7 @@
 import time
 from collections import defaultdict
 from enum import IntEnum
+from typing import Dict
 
 import attr
 
@@ -34,7 +35,7 @@ class ExtraInformation:
 
     def __repr__(self):
         return "ExtraInformation({})".format(
-            ", ".join([f"{k}={v!r}" for k, v in self.__dict__.items()]),
+            ", ".join(f"{k}={v!r}" for k, v in self.__dict__.items()),
         )
 
     def has_information(self):
@@ -51,15 +52,15 @@ class Status(IntEnum):
         return f"Status.{self.name}"
 
 
-@attr.s(frozen=True, slots=True)
+@attr.s(frozen=True, slots=True, auto_attribs=True)
 class StructuralCoverageTag:
-    label = attr.ib()
+    label: int
 
 
-STRUCTURAL_COVERAGE_CACHE = {}
+STRUCTURAL_COVERAGE_CACHE: Dict[int, StructuralCoverageTag] = {}
 
 
-def structural_coverage(label):
+def structural_coverage(label: int) -> StructuralCoverageTag:
     try:
         return STRUCTURAL_COVERAGE_CACHE[label]
     except KeyError:
