@@ -56,6 +56,19 @@ BIASED_COIN_INNER_LABEL = calc_label_from_name("inside biased_coin()")
 SAMPLE_IN_SAMPLER_LABLE = calc_label_from_name("a sample() in Sampler")
 ONE_FROM_MANY_LABEL = calc_label_from_name("one more from many()")
 
+INT_SIZES = (8, 16, 32, 64, 128)
+INT_WEIGHTS = (4.0, 8.0, 1.0, 1.0, 0.5)
+
+
+def unbounded_integers(data):
+    size = INT_SIZES[Sampler(INT_WEIGHTS).sample(data)]
+    r = data.draw_bits(size)
+    sign = r & 1
+    r >>= 1
+    if sign:
+        r = -r
+    return int(r)
+
 
 def integer_range(data, lower, upper, center=None):
     assert lower <= upper
@@ -76,7 +89,7 @@ def integer_range(data, lower, upper, center=None):
     elif center == lower:
         above = True
     else:
-        above = boolean(data)
+        above = not boolean(data)
 
     if above:
         gap = upper - center
@@ -90,11 +103,10 @@ def integer_range(data, lower, upper, center=None):
 
     if bits > 24 and data.draw_bits(3):
         # For large ranges, we combine the uniform random distribution from draw_bits
-        # with the weighting scheme used by WideRangeIntStrategy with moderate chance.
-        # Cutoff at 2 ** 24 so unicode choice is uniform but 32bit distribution is not.
-        idx = Sampler([4.0, 8.0, 1.0, 1.0, 0.5]).sample(data)
-        sizes = [8, 16, 32, 64, 128]
-        bits = min(bits, sizes[idx])
+        # with a weighting scheme with moderate chance.  Cutoff at 2 ** 24 so that our
+        # choice of unicode characters is uniform but the 32bit distribution is not.
+        idx = Sampler(INT_WEIGHTS).sample(data)
+        bits = min(bits, INT_SIZES[idx])
 
     while probe > gap:
         data.start_example(INTEGER_RANGE_DRAW_LABEL)
